@@ -109,3 +109,24 @@ def run_state_test_generators(runner_name: str,
                     preset_name=preset_name,
                     all_mods=all_mods,
                 ))
+
+
+def combine_mods(dict_1, dict_2):
+    """
+    Return the merged dicts, where the result value would be a list of the values from two dicts.
+    """
+    # The duplicate dict_1 items would be ignored here.
+    dict_3 = {**dict_1, **dict_2}
+
+    intersection = dict_1.keys() & dict_2.keys()
+    for key in intersection:
+        # To list
+        if not isinstance(dict_3[key], List):
+            dict_3[key] = [dict_3[key]]
+        # Append dict_1 value to list
+        if isinstance(dict_1[key], List):
+            dict_3[key] += dict_1[key]
+        else:
+            dict_3[key].append(dict_1[key])
+
+    return dict_3
