@@ -15,13 +15,18 @@ class PowChain:
         assert offset <= 0
         return self.blocks[offset - 1]
 
+    def to_dict(self):
+        return {
+            block.block_hash: block
+            for block in self.blocks
+        }
+
 
 def prepare_random_pow_block(spec, rng=Random(3131)):
     return spec.PowBlock(
         block_hash=spec.Hash32(spec.hash(bytearray(rng.getrandbits(8) for _ in range(32)))),
         parent_hash=spec.Hash32(spec.hash(bytearray(rng.getrandbits(8) for _ in range(32)))),
         total_difficulty=uint256(0),
-        difficulty=uint256(0)
     )
 
 
